PaperlessClient

Struct PaperlessClient 

pub struct PaperlessClient {
    pub request_full_permissions: bool,
    pub request_full_content: bool,
    /* private fields */
}
Client to interact with Paperless.

Fields

request_full_permissions: bool

Whether to request full permissions data for items.

request_full_content: bool

Whether to always request the full document content.

Implementations

Source

impl PaperlessClient

pub fn new( base_url: &str, token: &str, headers: Option<&HashMap<String, String>>, ) -> Result<Self, String>

Create a new Paperless client.

Arguments
  • base_url - The base URL of the Paperless API.
  • token - The authentication token for the Paperless API.
  • headers - Optional additional headers to include in requests.
pub fn new_with_client( base_url: &str, token: &str, headers: Option<&HashMap<String, String>>, client_builder: ClientBuilder, ) -> Result<Self, String>

Create a new Paperless client.

Provide a reqwest::ClientBuilder to customize the HTTP client, such as adding custom headers or disabling compression.

Arguments
  • base_url - The base URL of the Paperless API.
  • token - The authentication token for the Paperless API.
  • headers - Optional additional headers to include in requests.
  • client_builder - reqwest::ClientBuilder to use for creating the HTTP client.
pub fn with_full_permissions(self, req: bool) -> Self

Sets whether to request full permissions data for items during refresh.

If not enabled only simple permission data is loaded. See ItemPermissions for more details.

pub fn with_full_content(self, full_content: bool) -> Self

pub async fn refresh_all(&mut self) -> Result<(), Error>

Refresh and cache all metadata.

Only updates the cache for this instance, cloned instances will not see the changes.

pub async fn refresh( &mut self, data: impl IntoIterator<Item = RefreshMetaData>, ) -> Result<(), Error>

Refresh and cache the selected metadata.

Only updates the cache for this instance, cloned instances will not see the changes.

Arguments
  • data - The metadata to refresh.
  • full_permissions - Whether to use request full permissions data for the items being refreshed.
pub async fn query_documents( &self, query: DocumentQueryBuilder, ) -> Result<Vec<Document>, Error>

Query documents using the given DocumentQueryBuilder.

pub fn get_documents_by_tags( &self, tag_ids: &[TagId], ) -> impl Future<Output = Result<Vec<Document>, Error>>

Get all documents with any of the given tags.

pub async fn get_document_by_id( &self, id: DocumentId, ) -> Result<Document, Error>

Get a document by its ID.

pub async fn get_task_status( &self, task_id: Option<&TaskId>, task_name: Option<&str>, acknowledged: Option<bool>, ) -> Result<Vec<Task>, Error>

Get all tasks with optional filtering by ID, name, or acknowledged status.

pub fn get_workflows( &self, ) -> impl Future<Output = Result<Vec<Workflow>, Error>>

Get all workflows.

pub fn get_saved_views( &self, ) -> impl Future<Output = Result<Vec<SavedView>, Error>>

Get all saved views.

pub fn get_statistics(&self) -> impl Future<Output = Result<Statistics, Error>>

Get server statistics.

pub fn get_status(&self) -> impl Future<Output = Result<ServerStatus, Error>>

Get server status.

pub async fn create<T: Item>( &self, new_item: &T::CreateDto, ) -> Result<T::BaseType, Error>

Create a new item in Paperless.

All structs which implement CreateDtoObject can be used as new_item.

Returns the created item.

pub async fn update<T: Item>( &self, id: T::Id, update: &T::UpdateDto, ) -> Result<T::BaseType, Error>

Updates an existing item in Paperless.

All structs which implement UpdateDtoObject can be used as item.

pub async fn delete<T: Item>(&self, id: T::Id) -> Result<(), Error>

Deletes an existing item in Paperless.

pub async fn upload_document( &self, file_path: &Path, filename: &str, ) -> Result<TaskId, Error>

Upload a document to Paperless.

Returns the task ID on success.

pub fn tags(&self) -> &HashMap<TagId, Tag>

Get the tags cache.

pub fn storage_paths(&self) -> &HashMap<StoragePathId, StoragePath>

Get the storage paths cache.

pub fn find_tag_by_name(&self, name: &str) -> Option<&Tag>

Find a tag by its name.

pub fn document_types(&self) -> &HashMap<DocumentTypeId, DocumentType>

Get the document types cache.

pub fn find_document_type_by_name(&self, name: &str) -> Option<&DocumentType>

Find a document type by its name.

pub fn correspondents(&self) -> &HashMap<CorrespondentId, Correspondent>

Get the correspondents cache.

pub fn custom_fields(&self) -> &HashMap<CustomFieldId, CustomField>

Get the custom fields cache.

pub fn find_custom_field_by_name(&self, name: &str) -> Option<&CustomField>

Find a custom field by its name.

pub fn users(&self) -> &HashMap<UserId, User>

Get the users cache.

pub fn groups(&self) -> &HashMap<GroupId, Group>

Get the groups cache.