pub struct SearchHit {
pub score: f32,
pub highlights: Option<String>,
pub note_highlights: Option<String>,
pub rank: u32,
}Expand description
Search hit data
Fields
score: f32The score of the search hit.
highlights: Option<String>Highlight of the search hit in the document content.
note_highlights: Option<String>Highlight of the search hit in the note content.
rank: u32Rank of the search hit.