pub struct DocumentQueryBuilder { /* private fields */ }Expand description
Builder for constructing document queries.
Implementations
Sourceimpl DocumentQueryBuilder
impl DocumentQueryBuilder
Sourcepub fn archive_serial_number(
self,
archive_serial_number: ArchiveSerialNumber,
) -> Self
pub fn archive_serial_number( self, archive_serial_number: ArchiveSerialNumber, ) -> Self
Filters documents which have the given archive serial number.
Sourcepub fn correspondent_id_in(
self,
correspondent_id_in: Vec<CorrespondentId>,
) -> Self
pub fn correspondent_id_in( self, correspondent_id_in: Vec<CorrespondentId>, ) -> Self
Filters documents which have any of the given correspondents.
Sourcepub fn correspondent_name_icontains(
self,
correspondent_name_icontains: String,
) -> Self
pub fn correspondent_name_icontains( self, correspondent_name_icontains: String, ) -> Self
Filters documents which have a correspondent name containing the given string.
Sourcepub fn content_icontains(self, content_icontains: String) -> Self
pub fn content_icontains(self, content_icontains: String) -> Self
Filters documents which have content containing the given string.
Filters documents which have any of the given tags.
Sourcepub fn full_content(self, full_content: bool) -> Self
pub fn full_content(self, full_content: bool) -> Self
Returns documents with full content (truncated by default to save bandwidth).
Sourcepub fn full_permissions(self, full_permissions: bool) -> Self
pub fn full_permissions(self, full_permissions: bool) -> Self
Returns documents with full permissions data.
Sourcepub fn build(self) -> DocumentQuery
pub fn build(self) -> DocumentQuery
Builds the query.