Paperless ID types.
Paperless uses numeric IDs for most entities. To avoid confusion, ID types are defined as wrappers around the underlying numeric type. e.g. DocumentId(u32)
Paperless ID types.
Paperless uses numeric IDs for most entities. To avoid confusion, ID types are defined as wrappers around the underlying numeric type. e.g. DocumentId(u32)