pub struct FullPermissions {
pub view: Permission,
pub change: Permission,
}Expand description
The full permissions for a paperless item.
Fields
view: PermissionThe users and groups that can view the item.
change: PermissionThe users and groups that can change the item.