pub struct CreateSavedView {
pub name: String,
pub show_on_dashboard: bool,
pub show_in_sidebar: bool,
pub sort_field: Option<String>,
pub sort_reverse: Option<bool>,
pub filter_rules: Option<Vec<FilterRule>>,
pub display_mode: Option<DisplayMode>,
pub display_fields: Option<Vec<String>>,
pub page_size: Option<u32>,
}Fields
name: StringThe name of the saved view.
show_on_dashboard: boolWhether the saved view should be shown on the dashboard.
Whether the saved view should be shown in the sidebar.
sort_field: Option<String>The field to sort the view by.
sort_reverse: Option<bool>Whether to sort the view in reverse order.
filter_rules: Option<Vec<FilterRule>>The filter rules determining which documents are shown in the view.
display_mode: Option<DisplayMode>The display mode of the view.
display_fields: Option<Vec<String>>The fields to display in the view.
page_size: Option<u32>The number of documents to show per page.