pub struct UpdateSavedView {
pub name: Option<String>,
pub show_on_dashboard: Option<bool>,
pub show_in_sidebar: Option<bool>,
pub sort_field: Option<Option<String>>,
pub sort_reverse: Option<Option<bool>>,
pub filter_rules: Option<Option<Vec<FilterRule>>>,
pub display_mode: Option<Option<DisplayMode>>,
pub display_fields: Option<Option<Vec<String>>>,
pub page_size: Option<Option<u32>>,
}Fields
name: Option<String>The name of the saved view.
show_on_dashboard: Option<bool>Whether the saved view should be shown on the dashboard.
Whether the saved view should be shown in the sidebar.
sort_field: Option<Option<String>>The field to sort the view by.
sort_reverse: Option<Option<bool>>Whether to sort the view in reverse order.
filter_rules: Option<Option<Vec<FilterRule>>>The filter rules determining which documents are shown in the view.
display_mode: Option<Option<DisplayMode>>The display mode of the view.
display_fields: Option<Option<Vec<String>>>The fields to display in the view.
page_size: Option<Option<u32>>The number of documents to show per page.