#[non_exhaustive]pub enum RefreshMetaData {
Tags,
CustomFields,
Correspondents,
DocumentTypes,
Groups,
Users,
StoragePaths,
}Expand description
Selects which cached metadata to refresh.
Cached data is data which is rarly updated, refreshing it is normally not necessary on every request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.