Document

Struct Document 

pub struct Document { /* private fields */ }
Represents a document.

Changes made through mutating methods such as set_title, set_content, add_tag, and set_custom_field are only tracked locally at first.

They are not sent to the Paperless server until patch is called.

Implementations

Source

impl Document

pub fn id(&self) -> DocumentId

Get the unique identifier of the document.

pub fn archive_serial_number(&self) -> Option<ArchiveSerialNumber>

Get the archive serial number of the document.

pub fn added(&self) -> &DateTime<Utc>

Get the timestamp when the document was added.

pub fn created(&self) -> Option<&NaiveDate>

Get the created timestamp of the document.

pub fn modified(&self) -> &DateTime<Utc>

Get the modified timestamp of the document.

pub fn title(&self) -> &str

Get the title of the document.

pub fn original_file_name(&self) -> &str

Get the original file name of the document.

pub fn correspondent(&self) -> Option<CorrespondentId>

Get the correspondent id of the document.

pub fn owner(&self) -> Option<UserId>

Get the owner id of the document.

pub fn document_type(&self) -> Option<DocumentTypeId>

Get the document type id of the document.

pub fn page_count(&self) -> u32

Get the number of pages in the document.

pub fn tags(&self) -> &[TagId]

Get all tag-ids for the document.

pub fn custom_fields(&self) -> &[DocumentCustomField]

Get all custom fields for the document.

pub fn content(&self) -> Content<'_>

Get the content of the document.

pub fn storage_path(&self) -> Option<StoragePathId>

Get the storage path of the document.

pub fn notes(&self) -> &[Note]

Get the notes for the document.

pub fn permissions(&self) -> &ItemPermissions

Get the permissions for the document.

pub fn add_tag(&mut self, tag_id: TagId)

Add a tag to the document.

pub fn remove_tag(&mut self, tag_id: TagId)

Remove a tag from the document.

pub fn set_title(&mut self, title: &str)

Set the title of the document.

pub fn set_content(&mut self, content: &str)

Set the content of the document.

pub fn set_custom_field(&mut self, field: CustomFieldId, value: &str)

Set a custom field for the document.

pub fn remove_custom_field(&mut self, field: CustomFieldId)

Remove a custom field from the document.

pub fn set_created(&mut self, created: NaiveDate)

Set the created date of the document.

pub fn set_owner(&mut self, owner: UserId)

Set the owner of the document.

pub fn set_correspondent(&mut self, correspondent: CorrespondentId)

Set the correspondent of the document.

pub fn set_document_type(&mut self, document_type: DocumentTypeId)

Set the document type of the document.

pub fn set_storage_path(&mut self, storage_path: StoragePathId)

Set the storage path of the document.

pub fn is_dirty(&self) -> bool

Returns true if the document has unsaved changes.

pub fn is_deleted(&self) -> bool

Returns true if the document was deleted.

pub async fn refresh(&mut self) -> Result<(), Error>

Refresh the document from the server.

This will discard any local changes and replace them with the server’s state.

pub async fn patch(&mut self) -> Result<(), Error>

Update the document on the server.

This applies the currently tracked local changes to the remote Paperless document.

pub async fn delete(&mut self) -> Result<(), Error>

pub async fn get_full_content(&mut self) -> Result<(), Error>

Get the full content of the document, replacing any truncated content.

pub async fn download_to_buffer(&self) -> Result<Vec<u8>, Error>

Download the document to a buffer.

pub async fn download_to_file(&self, path: &Path) -> Result<(), Error>

Download the document to a file, requires the tokio-fs feature.

Generates a share link for the document that expires after the specified duration.

Generates a share link for the document that expires at the specified time.