DocumentQueryBuilder

Struct DocumentQueryBuilder 

pub struct DocumentQueryBuilder { /* private fields */ }
Builder for constructing document queries.

Implementations

Source

impl DocumentQueryBuilder

pub fn archive_serial_number( self, archive_serial_number: ArchiveSerialNumber, ) -> Self

Filters documents which have the given archive serial number.

pub fn correspondent_id_in( self, correspondent_id_in: Vec<CorrespondentId>, ) -> Self

Filters documents which have any of the given correspondents.

pub fn correspondent_name_icontains( self, correspondent_name_icontains: String, ) -> Self

Filters documents which have a correspondent name containing the given string.

pub fn content_icontains(self, content_icontains: String) -> Self

Filters documents which have content containing the given string.

pub fn tags_id_in(self, tags_id_in: Vec<TagId>) -> Self

Filters documents which have any of the given tags.

pub fn full_content(self, full_content: bool) -> Self

Returns documents with full content (truncated by default to save bandwidth).

pub fn full_permissions(self, full_permissions: bool) -> Self

Returns documents with full permissions data.

pub fn build(self) -> DocumentQuery

Builds the query.