Module workflow

Module workflow 

Types related to paperless workflows.

Structs

UpdateWorkflow
WebhookAction
A webhook action that can be executed when a workflow is triggered.
Workflow
A workflow
WorkflowAction
An action that can be executed when a workflow is triggered.
WorkflowTrigger
A trigger that determines when a workflow is executed.

Enums

WorkflowActionType
The type of action that is executed when a workflow is triggered.
WorkflowTriggerType
The type of trigger that determines when a workflow is executed.