Types related to paperless workflows.
Structs
- Webhook
Action - A webhook action that can be executed when a workflow is triggered.
- Workflow
- A workflow
- Workflow
Action - An action that can be executed when a workflow is triggered.
- Workflow
Trigger - A trigger that determines when a workflow is executed.
Enums
- Workflow
Action Type - The type of action that is executed when a workflow is triggered.
- Workflow
Trigger Type - The type of trigger that determines when a workflow is executed.